@@ -1,6 +1,6 @@
 package App::GitGot::Command::add;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::add::VERSION = '1.333';
+$App::GitGot::Command::add::VERSION = '1.334';
 # ABSTRACT: add a new repo to your config
 use 5.014;
 
@@ -8,7 +8,7 @@ use Class::Load              qw/ try_load_class /;
 use Config::INI::Reader;
 use Cwd;
 use IO::Prompt::Simple;
-use List::AllUtils           qw/ any pairmap /;
+use List::Util               qw/ any pairmap /;
 use Path::Tiny;
 use PerlX::Maybe;
 use Types::Standard -types;
@@ -133,7 +133,7 @@ App::GitGot::Command::add - add a new repo to your config
 
 =head1 VERSION
 
-version 1.333
+version 1.334
 
 =head1 SYNOPSIS
 
